<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el_GR">
<context>
    <name>MainWindow</name>
    <message>
        <source>Basic Downloader</source>
        <translation>Βασική λήψη</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>Λήψη λίστας</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>Εισαγωγή URL:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Λήψη</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Κωδικός μορφής</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Επέκταση</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Ανάλυση</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Όνομα μηχανής:</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>Επικόλληση περιεχομένου προχείρου</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>Πρόσφατα χρησιμοποιημένες</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>Ορισμός επιλογών λήψης</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>Μαζική λήψη</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Μικρογραφία</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>URL για λήψη</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>Επικόλληση URL προχείρου</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>Εποπτεία προχείρου για URL</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>Προσθήκη URL στη λίστα</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Ορισμός</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>Λήψη λίστας αναπαραγωγής</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>Επιλογές λήψης:</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation>Χρονικό μεσοδιάστημα ώρας έναρξης (HH:MM:SS):</translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation>Χρονικό μεσοδιάστημα ώρας λήξης (HH:MM:SS):</translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation>Κεφάλαια (διαχωρισμένα με κόμμα):</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Διαίρεση κατά κεφάλαια</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Απόκρυψη</translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>Εισαγωγή URL λίστας αναπαραγωγής:</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>Εκκαθάριση εσωτερικού αρχείου αρχειοθήκης</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>Χρήση εσωτερικού αρχείου αρχειοθήκης</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Βιβλιοθήκη</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Τύπος</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Επάνω</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Ανανέωση</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Αρχική</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Διαμόρφωση</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>Γενικές επιλογές</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>Εμφάνιση εικονιδίου στη γραμμή συστήματος</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>Αυτόματη αποθήκευση λίστας μη αποθηκευμένων μέσων</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation>Αυτόματη απόκρυψη λήψεων όταν ολοκληρώνονται</translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>Επαναφορά επιλογής στην προεπιλογή της</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Ορισμός προεπιλογών</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Επιλογές προρύθμισης</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>Διαδρομή λήψης</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>Επιλογή γλώσσας</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation>Χρήση χειροκίνητης διαμόρφωσης καθορισμένης μεσολάβησης</translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation>Λήψη διαμόρφωσης μεσολάβησης από το περιβάλλον</translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation>Χωρίς μεσολάβηση</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>Προεπιλεγμένες επιλογές μηχανής</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Μέγεθος αρχείου</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Επιλογές λήψης λίστας:</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Συνδρομές</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>Όνομα UI</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Τέλος</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>Ενεργοποίηση καρτέλας βιβλιοθήκης</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation>Μέγιστες ταυτόχρονες λήψεις</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Κωδικοποίηση κειμένου</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation>Εμφάνιση πληφοροφιών έκδοσης και αυτόματη λήψη ενημερώσεων</translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation>Εμφάνιση πληφοροφιών έκδοσης και πληροφοριών τελευταίας έκδοσης</translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation>Εμφάνιση μόνο πληφοροφιών έκδοσης</translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation>Καμία ενέργεια</translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation>Ενέργειες κατά την εκκίνηση</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Ιστότοπος</translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>Όνομα μηχανής</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Προεπιλογή</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>Επιλογές για προσθήκη</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>Διαχείριση URL</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Επιλογές λήψης</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>Ορίστε ποια URL θα πρέπει να διαχειρίζεται από ποια μηχανή</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>Φίλτρο URL</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation>Ρυθμίσεις μεσολάβησης</translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation>Χρήση διαμόρφωσης μεσολάβησης συστήματος</translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation>Χειροκίνητη διαμόρφωση καθορισμένης μεσολάβησης
Παράδειγμα 1: 192.168.93.89:8080
Παράδειγμα 2: ${gateway}:8080</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation>Αναπαραγωγή ληφθέντου μέσου</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation>Εισαγωγή URL λίστας αναπαραγωγής. Για να προσθέσετε πολλές λίστες αναπαραγωγής, διαχωρίστε τες με κενό ή νέα γραμμή</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Μετονομασία αρχείου στο παρακάτω κείμενο</translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation>Κουμπί για άνοιγμα φακέλου για να χρησιμοποιηθεί ως φάκελος λήψης</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation>Κουμπί για άνοιγμα φακέλου όπου είναι αποθηκευμένα τα αρχεία διαμόρφωσης θεμάτων</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation>Κουμπί για άνοιγμα φακέλου όπου είναι αποθηκευμένα τα διαδυκά επεκτάσεων</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation>Είστε βέβαιοι ότι θέλετε να επαναφέρετε αυτές τις επιλογές στις προεπιλογές τους;</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Όχι</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ναι</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation>Όνομα προγράμματος περιήγησης στον ιστό
για λήψη cookies</translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 Preset Options</source>
        <translation>Επιλογές προρύθμισης %1</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation>Το όνομα αρχείου με επέκταση &quot;.txt&quot; θα αποθηκεύει μόνο διευθύνσεις URL</translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation>Απόκρυψη σειράς</translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation>Επανεμφάνιση όλων των κρυφών σειρών</translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation>Απέτυχε η έναρξη του εκτελέσιμου %1</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Αντιγραφή URL</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation>Άνοιγμα URL με το %1</translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation>Αντιγραφή URL %1</translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>Αποθήκευση λίστας σε αρχείο</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>Απαντήσεις σε</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>Αποθήκευση υπότιτλου σε αρχείο</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Όνομα μηχανής:</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>Λήψη λίστας από αρχείο</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Επιλογές προρύθμισης</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Εκκαθάριση</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>Άνοιγμα φακέλου λήψης</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Έκδοση</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation>Σελίδα έργου</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Πνευματικά δικαιώματα</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Άδεια χρήσης</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Έκδοση Qt</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>Αυτό το πρόγραμμα είναι ελεύθερο λογισμικό; μπορείτε να το αναδιανείμετε ή/και να το τροποποιήσετε σύμφωνα με τους όρους της Γενικής Άδειας Δημόσιας Χρήσης GNU, όπως δημοσιεύεται από το Ίδρυμα Ελεύθερου Λογισμικού; είτε την έκδοση 2 της Άδειας, είτε (κατ&apos; επιλογή σας) οποιαδήποτε μεταγενέστερη έκδοση.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>Αυτό το πρόγραμμα διανέμεται με την ελπίδα ότι θα είναι χρήσιμο, αλλά ΧΩΡΙΣ ΚΑΜΙΑ ΕΓΓΥΗΣΗ; χωρίς καν την σιωπηρή εγγύηση της ΕΜΠΟΡΕΥΣΙΜΟΤΗΤΑΣ ή της ΚΑΤΑΛΛΗΛΟΤΗΤΑΣ ΓΙΑ ΕΝΑΝ ΣΥΓΚΕΚΡΙΜΕΝΟ ΣΚΟΠΟ. Δείτε τη Γενική Άδεια Δημόσιας Χρήσης GNU για περισσότερες λεπτομέρειες.</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>Πολωνικά (Πολωνία)</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>Αγγλικά (ΗΠΑ)</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>Ισπανικά (Ισπανία)</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>Κινεζικά (Κίνα)</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>Τουρκικά (Τουρκία)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>Ρωσικά (Ρωσία)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>Ιαπωνικά (Ιαπωνία)</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>Γαλλικά (Γαλλία)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>Ιταλικά (Ιταλία)</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>Σουηδικά (Σουηδία)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation>Γερμανικά (Γερμανία)</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>Πορτογαλικά (Βραζιλία)</translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation>Ολλανδικά (Ολλανδία)</translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>Σφάλμα, δεν ήταν δυνατή η εύρεση του εκτελέσιμου στο backend &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>Η μηχανή &quot;%1&quot; απαιτεί τουλάχιστον την έκδοση &quot;%2&quot; του Media Downloader</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>Για να απενεργοποιήσετε αυτούς τους ελέγχους, κάντε τα ακόλουθα:-</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>1. Μεταβείτε στην καρτέλα &quot;Διαμόρφωση&quot;.</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>2. Μεταβείτε στην υποκαρτέλα &quot;Γενικές επιλογές&quot;.</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation>3. Κάντ εκλικ στο μενού &quot;Ενέργειες κατά την εκκίνηση&quot;.</translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation>4. Επιλέξτε &quot;Καμία ενέργεια&quot;.</translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation>Εκτελείται σε φορητή λειτουργία</translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation>Εκετελείται σε εγκατεστημένη λειτουργία</translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation>Διαδρομή λήψης: %1</translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation>Διαδρομή δεδομένων εφαρμογής: %1</translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation>Ορισμός διεύθυνσης διακομιστή μεσολάβησης %1</translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation>Αναίρεση ορισμού διεύθυνσης διακομιστή μεσολάβησης</translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>Σφάλμα, απέτυχε η ανάλυση του αρχείου διαμόρφωσης &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>Απέτυχε η φόρτωση πρόσθετου</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>Απέτυχε η εύρεση του εκτελέσιμου &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>Απέτυχε η εύρεση του εκτελέσιμου python3 στο backend &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation>Παρουσιάστηκε σφάλμα δικτύου</translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation>Η URL δεν υποστηρίζεται</translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>Η λήψη ακυρώθηκε</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation>Κωδικός σφάλματος</translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation>Η λήψη απέτυχε, η μηχανή απέτυχε να ξεκινήσει</translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation>Η λήψη απέτυχε, η μηχανή κατέρρευσε</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Κωδικός μορφής</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Επέκταση</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Ανάλυση</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>Απέτυχε το άνοιγμα αρχείου για εγγραφή</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>Απέτυχε το άνοιγμα αρχείου για ανάγνωση</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>Χρόνος που παρήλθε:</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>Απέτυχε η εύρεση πληροφοριών έκδοσης, βεβαιωθείτε ότι το &quot;%1&quot; είναι εγκατεστημένο και λειτουργεί σωστά</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>Βρέθηκε η έκδοση</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation>Απέτυχε το άνοιγμα διαδρομής για εγγραφή: %1</translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation>Απέτυχε η εξαγωγή</translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>Το δίκτυο απέτυχε να αποκριθεί εντός %1 δευτερολέπτων</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>Απέτυχε η λήψη, δεν είναι δυνατή η δημιουργία της ακόλουθης διαδρομής: </translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>Έναρξη λήψης</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation>Προβλήματα, απέτυχε η διαγραφή του φακέλου: %1</translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation>Απέτυχε η εύρεση του εκτέλεσιμου &quot;bsdtar.exe&quot;</translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>Η λήψη απέτυχε</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>Απέτυχε η ανάλυση του αρχείου json από το github</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Λήψη</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Προορισμός</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation>Η ενημέρωση ολοκληρώθηκε, επανεκκινήστε για να χρησιμοποιήσετε τη νέα έκδοση</translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation>Ασφαλές κανάλι των Windows</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>Το αρχείο δεν βρέθηκε</translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>Η λήψη ολοκληρώθηκε</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>Εξαγωγή αρχειοθήκης: </translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>Η λήψη ολοκληρώθηκε</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>Επαναφορά φακέλου λήψης στην προεπιλογή</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>Μετεπεξεργασία</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Λήψη</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>Επιβολή λήψης</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>Εμφάνιση παραθύρου καταγραφής</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>Ημερομηνία μεταφόρτωσης:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Διάρκεια:</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>Όνομα υπότιτλου</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Επιλογές λήψης</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>Επιπλέον επιλογές λήψης</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>Μεσοδιάστημα χρόνου λήψης</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation>Λήψη κεφαλαίων</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Διαίρεση κατά κεφάλαια</translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>Το μέσο υπάρχει ήδη στην αρχειοθήκη</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Dark</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Μέθοδος</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>Χρόνος που απομένει</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Λήφθηκε</translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation>Το %1 λήφθηκε ήδη</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Αυτό μπορεί να διαρκέσει πάρα πολύ ώρα</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>Ταχύτητα:</translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation>Υπάρχει μια ενημέρωση για το %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation>Η νεότερη έκδοση είναι %1, ενημέρωση</translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation>Έλεγχος εγκατεστημένης έκδοσης του %1</translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation>Βρέθηκε η έκδοση: %1</translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation>Η νεότερη έκδοση είναι: %1</translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation>Παρακαλώ ενημερώστε το &quot;%1&quot; τουλάχιστον στην έκδοση &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation>Η ζητούμενη μορφή δεν είναι διαθέσιμη</translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation>Εισήχθη μη έγκυρη URL</translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation>Μόνο βέλτιστος διαθέσιμος ήχος</translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation>Μόνο βέλτιστος διαθέσιμος ήχος (MP3)</translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation>Βέλτιστος διαθέσιμος ήχος βίντεο</translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation>Βέλτιστος ήχος με ανάλυση βίντεο %1</translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation>Προειδοποίηση: Παράλειψη περιεχομένου προχείρου</translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation>Εμφάνιση πρώτα φακέλων</translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation>Τακτοποίηση σε αύξουσα σειρά</translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation>Τακτοποίηση κατά ημερομηνία</translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation>Τακτοποίηση κατά όνομα</translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation>Τακτοποίηση σε φθίνουσα σειρά</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Φίλτρο</translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation>Χωρίς φίλτρο</translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation>Άλλοι ιστότοποι</translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation>Εξαγωγή ήχου</translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation>Εξαγωγή ήχου ως MP3</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Αραβικά</translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation>Μόνο βέλτιστος διαθέσιμος ήχος+Μικρογραφία</translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation>Youtube</translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation>Η αυτόματη ενημέρωση είναι απενεργοποιημένη για %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation>Η νεότερη έκδοση είναι %1, η αυτόματη ενημέρωση είναι απενεργοποιημένη</translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation>Συντάκτης: %1</translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation>Πλήθος &quot;Μου αρέσει&quot;: %1</translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation>Κορεατικά (Κορέα)</translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation>Εισέλθετε για να επιβεβαιώσετε ότι δεν είστε bot</translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation>Εμφάνιση/Απόκρυψη στοιχείων ελέγχου</translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation>Συγχώνευση ήχου και βίντεο μαζί</translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation>Ελληνικά (Ελλάδα)</translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation>Μετατροπή βίντεο</translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation>Απόκρυψη λίστας</translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set Batch File</source>
        <translation>Ορισμός μαζικού αρχείου</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>Λήψη σχολίων</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Λήψη</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Αντιγραφή URL</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>Εμφάνιση υπότιτλων</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Εμφάνιση σχολίων</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>Εμφάνιση επιλογών μέσου</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>Λήψη τμήματος μέσου</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Ορισμός</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>Λήψη υπότιτλων</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation>Ταξινόμηση κατά αύξουσα ημερομηνία</translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation>Ταξινόμηση κατά φθίνουσα ημερομηνία</translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation>Ταξινόμηση κατά &quot;Μου αρέσει&quot;</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set As Default</source>
        <translation>Ορισμός ως προεπιλογή</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>Επιλογή αρχείου μηχανής</translation>
    </message>
    <message>
        <source>Set Download Folder</source>
        <translation>Ορισμός φακέλου λήψης</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Ορισμός προεπιλογών</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished">Όνομα προγράμματος περιήγησης στον ιστό
για λήψη cookies</translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Διαγραφή όλων</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation>Είστε βέβαιοι ότι θέλετε να διαγράψετε το παρακάτω αρχείο;</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation>Είστε βέβαιοι ότι θέλετε να διαγράψετε τον παρακάτω φάκελο;</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ναι</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Όχι</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation>Είστε βέβαιοι ότι θέλετε να διαγράψετε όλα τα αρχεία και τους φακέλους;</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Μετονομασία αρχείου στο παρακάτω κείμενο</translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation>Μετονομασία φακέλου στο παρακάτω κείμενο</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation>Είστε βέβαιοι ότι θέλετε να διαγράψετε τα επιλεγμένα στοιχεία;</translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Log Window</source>
        <translation>Παράθυρο καταγραφής</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Εκκαθάριση</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation>Απόκρυψη στοιχείων ελέγχου</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Λήψη επιλογών λίστας:</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Αντιγραφή URL</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Εμφάνιση σχολίων</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>Εμφάνιση όλων των ενημερωμένων</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>Λήψη όλων των ενημερωμένων</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>Διαχείριση συνδρομών</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>Αριθμός σελίδων που λήφθηκαν</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>Λήψη πληροφορίων βίντεο</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation>Εμφάνιση στοιχείων ελέγχου</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Εμφάνιση</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Απόκρυψη</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Αυτό μπορεί να διαρκέσει παρα πολύ ώρα</translation>
    </message>
</context>
</TS>
